@@ -28,6 +28,7 @@ from zope.lifecycleevent import ObjectMovedEvent
 
 import mock
 import pkg_resources
+import six
 import unittest
 
 
@@ -163,7 +164,7 @@ class TestPloneApiContent(unittest.TestCase):
         # in the InvalidParameterError message
         self.assertIn(
             'No such content type: foo',
-            cm.exception.message,
+            str(cm.exception),
         )
 
         # Check the constraints for allowed types in the container
@@ -322,7 +323,7 @@ class TestPloneApiContent(unittest.TestCase):
         def force_unicode_error(object):
             raise UnicodeDecodeError(
                 'ascii',
-                'x',
+                b'x',
                 1,
                 5,
                 unicode_exception_message,
@@ -594,7 +595,11 @@ class TestPloneApiContent(unittest.TestCase):
                 container['about']['nu-contact'] == nucontact)
         assert 'contact' not in container['about'].keys()
 
-        self.assertItemsEqual(
+        if six.PY2:
+            assertCountEqual = self.assertItemsEqual
+        else:
+            assertCountEqual = self.assertCountEqual
+        assertCountEqual(
             firedEvents,
             [
                 ObjectMovedEvent,
@@ -917,7 +922,7 @@ class TestPloneApiContent(unittest.TestCase):
     def _set_text(self, obj, text):
         if IDexterityContent.providedBy(obj):
             # Dexterity
-            obj.text = RichTextValue(text)
+            obj.text = RichTextValue(text, 'text/html', 'text/x-html-safe')
         else:
             # Archetypes
             obj.setText(text, mimetype='text/html')
