@@ -12,6 +12,7 @@ from zope.interface import implementer
 from zope.interface import Interface
 
 import mock
+import six
 import unittest
 
 
@@ -510,6 +511,10 @@ class TestPloneApiGroup(unittest.TestCase):
 
     def test_local_roles_without_inheritance(self):
         """Test granting and getting local_roles."""
+        if six.PY2:
+            assertCountEqual = self.assertItemsEqual
+        else:
+            assertCountEqual = self.assertCountEqual
 
         api.group.create(groupname='foo')
 
@@ -532,12 +537,12 @@ class TestPloneApiGroup(unittest.TestCase):
         )
         # Add the editor-role as global role
         api.group.grant_roles(groupname='foo', roles=['Editor'])
-        self.assertItemsEqual(
+        assertCountEqual(
             ['Authenticated', 'Editor'],
             api.group.get_roles(groupname='foo'),
         )
         # local_roles plus global_roles
-        self.assertItemsEqual(
+        assertCountEqual(
             ['Authenticated', 'Editor'],
             api.group.get_roles(groupname='foo', obj=folder),
         )
@@ -551,7 +556,7 @@ class TestPloneApiGroup(unittest.TestCase):
         api.group.grant_roles(
             groupname='foo', roles=['Contributor'], obj=folder,
         )
-        self.assertItemsEqual(
+        assertCountEqual(
             ['Contributor'],
             api.group.get_roles(groupname='foo', obj=folder, inherit=False),
         )
@@ -603,6 +608,10 @@ class TestPloneApiGroup(unittest.TestCase):
     def test_local_roles_disregard_adapter(self):
         """Test that borg.localrole-adpaters are not copied when granting
         local roles."""
+        if six.PY2:
+            assertCountEqual = self.assertItemsEqual
+        else:
+            assertCountEqual = self.assertCountEqual
 
         portal = api.portal.get()
         folder = api.content.create(
@@ -636,12 +645,12 @@ class TestPloneApiGroup(unittest.TestCase):
         provideAdapter(LocalRoleProvider)
 
         # the adapter-role is added for get_role
-        self.assertItemsEqual(
+        assertCountEqual(
             api.group.get_roles(groupname='foo', obj=folder),
             ['Authenticated', 'Reviewer'],
         )
 
-        self.assertItemsEqual(
+        assertCountEqual(
             api.group.get_roles(groupname='foo', obj=folder, inherit=False),
             ['Reviewer'],
         )
@@ -650,18 +659,18 @@ class TestPloneApiGroup(unittest.TestCase):
         api.group.grant_roles(
             groupname='foo', roles=['Contributor'], obj=folder,
         )
-        self.assertItemsEqual(
+        assertCountEqual(
             api.group.get_roles(groupname='foo', obj=folder),
             ['Authenticated', 'Contributor', 'Reviewer'],
         )
 
         # The adapter role in in the local roles but not persistent
-        self.assertItemsEqual(
+        assertCountEqual(
             api.group.get_roles(groupname='foo', obj=folder, inherit=False),
             ['Contributor', 'Reviewer'],
         )
         local_roles = getattr(folder, '__ac_local_roles__', {})
-        self.assertItemsEqual(
+        assertCountEqual(
             local_roles.get('foo'),
             ['Contributor'],
         )
